@@ -1,8 +1,6 @@
 #include <unistd.h>
 #include <stdio.h>
-#include <errno.h>
 #include <string.h>
-#include "config.h"
 #include "tintin.h"
 
 int main()
@@ -11,12 +9,12 @@ int main()
     char buf[BUFFER_SIZE];
     int s,n,r;
 
-    while(1)
+    while (1)
     {
         if (read(0, &th, 12)!=12)
             return 0;
         n=from_little_endian(th.len);
-        while(n>0)
+        while (n>0)
         {
             s=(n>BUFFER_SIZE)?BUFFER_SIZE:n;
             if ((r=read(0, buf, s))<=0)
